<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>QApplication</name>
    <message>
        <source>MX Tweak</source>
        <translation type="obsolete">MX Ajustes Rápidos</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="obsolete">Esta aplicação é exclusiva do Xfce</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Janela Principal</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Brilho controlado pelo software (xrandr)</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>Rótulo de texto</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Retroiluminação do ecrã</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="30"/>
        <source>MX-Tweak</source>
        <translation>MX Ajustes Rápidos</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="56"/>
        <source>Display</source>
        <translation>Ecrã</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="61"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="52"/>
        <location filename="../defaultlook.cpp" line="67"/>
        <location filename="../defaultlook.cpp" line="586"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <location filename="../defaultlook.cpp" line="610"/>
        <location filename="../defaultlook.cpp" line="621"/>
        <source>MX Tweak</source>
        <translation>MX Ajustes Rápidos</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="147"/>
        <source>Xfce Settings</source>
        <translation>Definições do Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalizar o painel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="48"/>
        <location filename="../defaultlook.ui" line="161"/>
        <source>Panel</source>
        <translation>Painel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="68"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configurar o comportamento das janelas e os atalhos&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="82"/>
        <source>Window Manager</source>
        <translation>Gestor de Janelas</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="102"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalizar o aspecto da área de trabalho&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="116"/>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1642"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1653"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1670"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1673"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1680"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="169"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="189"/>
        <source>Backup current panel configuration</source>
        <translation>Guardar a configuração actual do painel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="196"/>
        <source>Restore backup panel configuration</source>
        <translation>Restaurar a configuração do painel guardada</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="203"/>
        <source>Restore default panel</source>
        <translation>Restaurar o painel pré-definido</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="216"/>
        <location filename="../defaultlook.ui" line="1311"/>
        <source>Affects 1st panel</source>
        <translation>Afecta o painel 1</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Display panel vertically</source>
        <translation>Exibir o painel na vertical</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <location filename="../defaultlook.ui" line="1329"/>
        <source>Bottom</source>
        <translation>Em baixo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="248"/>
        <location filename="../defaultlook.ui" line="1339"/>
        <source>Top</source>
        <translation>Em cima</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="256"/>
        <source>Display panel horizontally</source>
        <translation>Exibir o painel na horizontal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="276"/>
        <location filename="../defaultlook.ui" line="1334"/>
        <source>Left</source>
        <translation>À esquerda</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="281"/>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Right</source>
        <translation>À direita</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="289"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Afecta todos os painéis&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="309"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Botões de janela&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="324"/>
        <location filename="../defaultlook.ui" line="427"/>
        <location filename="../defaultlook.ui" line="618"/>
        <location filename="../defaultlook.ui" line="748"/>
        <location filename="../defaultlook.ui" line="871"/>
        <location filename="../defaultlook.ui" line="878"/>
        <location filename="../defaultlook.ui" line="971"/>
        <location filename="../defaultlook.ui" line="1287"/>
        <location filename="../defaultlook.ui" line="1425"/>
        <location filename="../defaultlook.ui" line="1569"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="361"/>
        <source>Theme Options</source>
        <translation>Opções de tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="391"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Corrigir alguns campos em páginas web ao usar o tema escuro</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="394"/>
        <source>Firefox dark theme tweak</source>
        <translation>Ajuste do tema escuro do Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="401"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Corrigir a caixa de entrada de dados do HexChat no tema escuro</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="453"/>
        <source>Undo</source>
        <translation>Reverter</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="460"/>
        <source>Preview</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="467"/>
        <source>Remove User Theme Set</source>
        <translation>Remover Tema de Utilizador</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="478"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Guardar as definições actuais como Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Abrir a ferramenta de configuração compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="516"/>
        <source>Compton settings</source>
        <translation>Definições do Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="540"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Definições do Compositor do Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="543"/>
        <source>Xfwm Settings</source>
        <translation>Definições do Xfwm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="567"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="572"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Compositor do Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="577"/>
        <source>Compton </source>
        <translation>Compositor Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="585"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Editar o ficheiro compton.conf directamente num editor de texto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Edit compton.conf</source>
        <translation>Editar o ficheiro compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="645"/>
        <source>Transparency and shadow options</source>
        <translation>Opções de transparência e sombreado</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="652"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Alterar o modo VBlank pode ajudar a aliviar alguns problemas de distorção no ecrã. Consultar a Ajuda para mais informação.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="655"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="663"/>
        <source>auto</source>
        <translation>automático</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="668"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="673"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="678"/>
        <source>off</source>
        <translation>desligado</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="888"/>
        <source>Config Options</source>
        <translation>Opções de configuração</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1447"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Restabelecer o tema pré-definido do écrã de entrada (LightDM) </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="896"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Restabelecer as acções pré-definidas do botão direito do rato no Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1470"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Usar o controlador intel em vez do controlador &quot;modsetting&quot; pré-definido (requer reiniciar)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1477"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          NOTA: o ficheiro /etc/X11/xorg.conf.d/20-intel.conf existente será guardado na pasta pessoal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1488"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Usar a opção de controlador amdgpu anti-distorção</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1495"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>          NOTA: o ficheiro /etc/X11/xorg.conf.d/20-amd.conf existente será guardado na pasta pessoal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1506"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Usar a opção de controlador radeon anti-distorção</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1513"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          NOTA: o ficheiro /etc/X11/xorg.conf.d/20-radeon.conf existente será guardado na pasta pessoal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>Display</source>
        <translation>Ecrã</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="707"/>
        <source>Hardware Backlight</source>
        <translation>Retroiluminação do ecrã</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="714"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ajustes do ecrã &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="741"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Escolher ecrã para ajustes de xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>Resolution</source>
        <translation>Resolução</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="781"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;A gravação é por exibição&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="784"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="791"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Brilho controlado pelo software (xrandr)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="798"/>
        <location filename="../defaultlook.ui" line="812"/>
        <source>TextLabel</source>
        <translation>Rótulo de texto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="805"/>
        <source>GTK scaling</source>
        <translation>Escala GTK</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="832"/>
        <source>xrandr Scaling</source>
        <translation>Escala xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="985"/>
        <source>Fluxbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1022"/>
        <location filename="../defaultlook.ui" line="1053"/>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1027"/>
        <location filename="../defaultlook.ui" line="1058"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1063"/>
        <source>On Hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1199"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="993"/>
        <location filename="../defaultlook.ui" line="1392"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1000"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1007"/>
        <source>Reset DefaultDock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1014"/>
        <source>Toggle desktop icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1035"/>
        <source>Reset Fluxbox Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1042"/>
        <source>Toggle icon captions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1084"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1091"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1098"/>
        <location filename="../defaultlook.ui" line="1206"/>
        <location filename="../defaultlook.ui" line="1318"/>
        <source>Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1172"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1182"/>
        <location filename="../defaultlook.ui" line="1280"/>
        <source>Autohide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1189"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>Plasma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1371"/>
        <source>Workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1378"/>
        <source>Enable single-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1399"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1439"/>
        <source>Other</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1536"/>
        <source>&amp;User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1543"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="917"/>
        <source>Show systray (notification area) frame</source>
        <translation>Mostrar o caixilho da bandeja (área de notificação)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="924"/>
        <location filename="../defaultlook.ui" line="1385"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Mostrar as janelas de todas as áreas de trabalho no painel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="903"/>
        <source>Enable single-click on desktop</source>
        <translation>Activar &apos;um clique&apos; na área de trabalho</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="938"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Activar &apos;Hibernar&apos; no menu Sair</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1454"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Activar a montagem de discos internos por utilizadores além do root (administrador)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1461"/>
        <source>Enable kernel sandbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="945"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>nota: para o sistema poder hibernar, a partição swap tem que ser &gt;= RAM instalada</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="931"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Desactivar o encurtamento de nomes de ficheiro extensos na área de trabalho</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="910"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Activar &apos;um clique&apos; no gestor de ficheiros Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1529"/>
        <source>Password for administrative tasks:</source>
        <translation>Senha para tarefas administrativas:</translation>
    </message>
    <message>
        <source>User</source>
        <translation type="vanished">Utilizador</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="53"/>
        <source>--display switch only valid for Xfce</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="585"/>
        <source>About MX Tweak</source>
        <translation>Sobre o MX Ajustes Rápidos</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="586"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="587"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Aplicação para rapidamente fazer alterações ao tema pré-definido da interface de utilizador e outros ajustes</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="589"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="590"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="591"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="622"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Concluído! O Firefox pode ter que ser reiniciado para as alterações terem efeito</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="vanished">Esta aplicação é exclusiva do Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="806"/>
        <source>Panel settings</source>
        <translation>Definições do painel</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="807"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>As actuais definições do painel foram guardadas numa pasta oculta chamada .restore na pasta pessoal (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1376"/>
        <source>settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1713"/>
        <source>Choose a theme set</source>
        <translation>Escolher um tema</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Remover Tema de Utilizador</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Novo Tema</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Introduzir o nome do novo Tema</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Botões de janela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aparência&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Mostrar rótulos dos botões</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Mostrar botões sem relevo</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Mostrar pega</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Ordenação:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Estampa de data/hora</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Título do grupo e estampa de data/hora</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Título da janela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Título do grupo e título da janela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Nenhum; permitir arrastar-e-largar</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Comportamento&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Agrupamento de janelas:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Acção do botão central:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Sem acção</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Fechar janela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimizar janela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Restaurar as janelas minimizadas na área de trabalho actual</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Desenhar caixilho da janela ao passar sobre um botão</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Mudar de janela com a roda do rato</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtrar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Mostrar janelas de todas as áreas de trabalho ou janelas embebidas</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Mostrar apenas janelas minimizadas</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Mostrar janelas de todos os monitores</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Caixa de diálogo</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Janelas emergentes (popup)</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Ao mover</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Definições de opacidade&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Moldura das janelas</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Mostrar sombreado nas janelas em doca</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Mostrar sombreado nas janelas emergentes (popup)</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Ao redimensionar</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Mostrar sombreado nas janelas normais</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Definições da funcionalidade&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Ao percorrer as janelas mostrar a pré-visualização em vez dos ícones</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Exibir directamente as janelas de sobreposição de écrã inteiro</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Janelas inactivas</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sincronizar o desenho com o traço em branco vertical</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Definições do Compositor do Xfwm</translation>
    </message>
</context>
</TS>
